MultiSelectDialog class

A customizable multi-select dialog for Flutter.

The MultiSelectDialog allows users to select multiple options from a list with support for search, titles, subtitles, and custom styling. The dialog can be displayed either as an AlertDialog or as a BottomSheet.

Inheritance

Constructors

MultiSelectDialog({Key? key, required String title, String? subtitle, required List<MultiSelectItem> items, List<MultiSelectItem>? selectedItems, required dynamic onConfirm(List<MultiSelectItem>), Color? backgroundColor, TextStyle? titleStyle, TextStyle? subtitleStyle, TextStyle? itemTitleStyle, TextStyle? itemSubtitleStyle, String cancelText = "Cancel", String confirmText = "Done", ButtonStyle? cancelButtonStyle, ButtonStyle? confirmButtonStyle, DialogDisplayType displayType = DialogDisplayType.alert})
Creates a new MultiSelectDialog.
const

Properties

backgroundColor Color?
Background color of the dialog.
final
cancelButtonStyle ButtonStyle?
Custom style for the cancel button.
final
cancelText String
Text for the cancel button (default: "Cancel").
final
confirmButtonStyle ButtonStyle?
Custom style for the confirm button.
final
confirmText String
Text for the confirm button (default: "Done").
final
displayType DialogDisplayType
Determines how the dialog is displayed.
final
hashCode int
The hash code for this object.
no setterinherited
items List<MultiSelectItem>
The list of items to display in the dialog.
final
itemSubtitleStyle TextStyle?
Custom text style for each item subtitle in the list.
final
itemTitleStyle TextStyle?
Custom text style for each item title in the list.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onConfirm → dynamic Function(List<MultiSelectItem>)
Callback triggered when the user presses the confirm button.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedItems List<MultiSelectItem>?
Preselected items when the dialog is first displayed.
final
subtitle String?
An optional subtitle displayed below the title.
final
subtitleStyle TextStyle?
Custom text style for the subtitle.
final
title String
The title displayed at the top of the dialog.
final
titleStyle TextStyle?
Custom text style for the title.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<MultiSelectDialog>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited