onConfirm property
Callback triggered when the user presses the confirm button.
Provides the list of selected MultiSelectItems.
Implementation
final Function(List<MultiSelectItem>) onConfirm;
Callback triggered when the user presses the confirm button.
Provides the list of selected MultiSelectItems.
final Function(List<MultiSelectItem>) onConfirm;