MultiSelectDialog class

Inheritance

Constructors

MultiSelectDialog({Key? key, required String title, String? subtitle, required List<MultiSelectItem> items, List<MultiSelectItem>? selectedItems, required dynamic onConfirm(List<MultiSelectItem>), Color? backgroundColor, TextStyle? titleStyle, TextStyle? subtitleStyle, TextStyle? itemTitleStyle, TextStyle? itemSubtitleStyle, String cancelText = "Cancel", String confirmText = "Done", ButtonStyle? cancelButtonStyle, ButtonStyle? confirmButtonStyle, DialogDisplayType displayType = DialogDisplayType.alert})
const

Properties

backgroundColor Color?
final
cancelButtonStyle ButtonStyle?
final
cancelText String
final
confirmButtonStyle ButtonStyle?
final
confirmText String
final
displayType DialogDisplayType
final
hashCode int
The hash code for this object.
no setterinherited
items List<MultiSelectItem>
final
itemSubtitleStyle TextStyle?
final
itemTitleStyle TextStyle?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onConfirm → dynamic Function(List<MultiSelectItem>)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedItems List<MultiSelectItem>?
final
subtitle String?
final
subtitleStyle TextStyle?
final
title String
final
titleStyle TextStyle?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<MultiSelectDialog>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited