MultiSelectItem<T> class
A model class representing an item in the multi-select dialog.
Each item has an id, title, an optional subtitle, and a value (which can be a String, int, or even a custom model).
The isChecked property indicates whether the item is currently selected.
Constructors
- MultiSelectItem({required String id, required T value, required String title, String? subtitle, bool isChecked = false})
-
Creates a MultiSelectItem with the given
id,value,title, optionalsubtitle, andisCheckedstate.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
A unique identifier for this item.
final
- isChecked ↔ bool
-
Whether this item is currently selected.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtitle → String?
-
An optional subtitle displayed under the title.
final
- title → String
-
The title displayed in bold in the multi-select UI.
final
- value → T
-
The actual value of this item.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited