MultiSelectItem<T> class

Constructors

MultiSelectItem({required String id, required T value, required String title, String? subtitle, bool isChecked = false})

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
final
isChecked bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitle String?
final
title String
final
value → T
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited